@@ -9,11 +9,12 @@ use strict;
 use warnings;
 use base qw( Tickit );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
 use POE;
+use POEx::Tickit::Driver;
 use Tickit;
 
 =head1 NAME
@@ -57,6 +58,7 @@ sub new
             _start   => "_poe_start",
             sigwinch => "_poe_sigwinch",
             input    => "_poe_input",
+            output   => "_poe_output",
             timer    => "_poe_timer",
             timeout  => "_poe_timeout",
             _stop    => "_poe_stop",
@@ -70,6 +72,16 @@ sub new
    return $self;
 }
 
+sub _make_writer
+{
+   my $self = shift;
+   my ( $out ) = @_;
+
+   $self->{writer} = POEx::Tickit::Driver->new(Handle => $out);
+
+   return $self->{writer};
+}
+
 sub _poe_start
 {
    my $self = $_[OBJECT];
@@ -79,6 +91,7 @@ sub _poe_start
    $_[KERNEL]->sig( WINCH => sigwinch => );
 
    $_[KERNEL]->select_read( $self->term->get_input_handle, input => );
+   $_[KERNEL]->select_write( $self->term->get_output_handle, output => );
 }
 
 sub _poe_stop
@@ -87,7 +100,8 @@ sub _poe_stop
 
    $_[KERNEL]->sig( WINCH => () );
 
-   $_[KERNEL]->select_read( $self->term->get_input_handle, () )
+   $_[KERNEL]->select_read( $self->term->get_input_handle, () );
+   $_[KERNEL]->select_write( $self->term->get_output_handle, () );
 }
 
 sub _poe_sigwinch
@@ -108,6 +122,15 @@ sub _poe_input
    _poe_timeout( @_ );
 }
 
+sub _poe_output
+{
+   my $self = $_[OBJECT];
+
+   my $term = $self->term;
+
+   $self->{writer}->flush( $self->term->get_output_handle );
+}
+
 sub _poe_timeout
 {
    my $self = $_[OBJECT];
